160,589 Commits over 4,566 Days - 1.47cph!
Optimize refreshing links after block is spawned & killed
- refreshing neighbors was causing faces to be queued multiple times, will now only queue each face at most once after changes
Apply the new collision ref collision to biofuel generator (just for testing)
Mark any mesh used for collision baking as ExcludeFromBundles so it won't be added to the build
Fix BoxColliderBake component having different serialization layout when building
Switch the tests with doors from unit tests -> automated tests
- was throwing errors after the navmesh was changed, figured may as well make automated
Merge from livestock_animals
Add missing shears effects
Update item description
Merge from CullWhenInside_vis_improvement
mainisland_roaming_scientistboats -> main
Updated CullWhenInside to run in a PersistentObjectWorkQueue with a 1s min lap time so it can't update too often. Has a 0.01ms budget so it generally can only process one a frame
Reduced LODManager budget to 0.05ms from 0.1ms
A large portion of LODManager ChangeLOD calls were spending all of their time in CullWhenInside due to it's expensive Vis check, by moving that out we should have more responsive LODs even with a smaller budget
Introduces a small delay when building over bushes, but we gain 0.05ms overall
When a boat’s driver dies another scientist now takes over driving
- 20% chance for scientist rhib to drop a blueprint page
- 20% chance for scientist pt boat to drop a blueprint book
Fix leg ik not working on the rear pt boat
Removing Primitive tech tree tax, as it was always rounding up to 2 blueprints used.
Merge from terrain_textures_review
- Boats in a group no longer pass a hidden player back and forth forever, they give up 45s after losing sight of him
- PT boat turrets look around when they have nothing to shoot at
- Roaming boats patrol closer to the coast, min shore distance 100m -> 35m
- Fixed killing the roaming boats event leaving behind boats spawned less than a second earlier
- Removed a duplicate line of sight check when roaming boats pick a target
Cache "is outside" score per set of connected rooms, only recalculate the rooms that were changed
- makes it cheaper to destroy / add blocks to buildings
Prototype Rust+ camera that renders real models, textures, etc. withn the app
Editor tooling exports mobile-friendly assets for uploading to our CDN
Optimize empty room search after blocks are destroyed
- track rooms when they have all faces removed and mark as destroyed instead of checking to see if any rooms need to be cleaned up
▇▍▌▋▌▄ ▇▋▌▇ █▅▊▅▇▋█▋▄▄▊▊██▍▊
▆▇█▇ ▍▇█▋▉▉ ▍▊▇▅ ▍▉▊█▍▇█▅▄ ▋▋▇▍ ▆▋▅▍ ▄█▉█▆▅▋ ▌▊ ▉ ▉▅██▍▆
Adjust recoil, weapon rack config
Optimize time taken when room occlusion is turned on at runtime (18s -> 4s)
- only visit every face once instead of refreshing nearby faces and calculating multiple times
Merge from livestock_animals
Hitting a sheeps skin with shears won't hurt or startle them (still does small amounts of damage to other entities)
Optimize network group assignment after a room is recalculated
▉▍▄█ █▇▅▊▉ ▋█▊▇█ ▉▉▅▊▅▍▅ ▆▊ ▉▊▋██▍ ▇▅▊▊▋▆▌ ▊▍▇█▍▊▌▌ ▉▋▇▄▉▊▍▆▋▆▊▆▆█ ▌▋ ▍▋▋▆▊▋▄ ▉▅▊▌ ▆▆▊▍▉█ ▌▄▌█▇▌ ▆█▌▌▇▄ ▄▉▆ ▄▊▉▆ ▌▊▆▋▋▋▌ ▌▌▊ ▄▅▇▄▌ ██▄▆▉ ▌▉▋ ▋▍▊▉▅▅▊▆ ▉▄ ▊▊ ▋▊ ▆▄▊█ ▄█▋▌ ▊▄▄▅▅▋ ▄▇▄ ▇▇▌█▌▅▆▋
Merge from swamp_tree_x_improvement
Lowered marker points on swamp_tree_f
Merge from Livestock_animals
Linux64 build progress
* Dedicated server builds successfully
VPC script cleanups for Linux64 client
Cleanup VPC scripts a bit so they are less messy
Remove more unused files from src/lib/
Fixed Linux compile warning to do with colliding macro names
More VPC script cleanups
StudioMDL Linux32 compile fixes
Delete prebuilt vpk_linux32
Only require an infant animal to reach 80% happiness in order to max out potential stat
Add [+firemode] to ReplaceTokens
▊ ▅▄▍ ██▆▊ ▊▄▍█ ▌▊ ▉▉▇▌▄█▌█ ▌▊▋▄▄▊▌▅▇ ▄▉▋▇▅▉▊
merge from fix_sail_guide_mismatch -> main
▋ ▊▋▌▌▋ ▋▄ ▆▄▍▉▋ ▋▆▊▇ ▄▉▄▇▌▊▍ ▌▌▋▌▊▌▇▄ ▌▆ ▊▆▌▊▆ ▍▊▆▅▅█▌▆ ▅▋ ▌▄▊ ▍▆▌▍ ▍▌▄▄▄ ▌██▊▌▊▉▄▍▌▊▋▉▇▅▋▉▉▄▉▉▄▋▋▊▅▊█ ▋▇▍ ▊▆▍▌▋▊ ▉▊▅ ▋▄▌▍▇▌▇▌ ▋▆█▇▄█▉▋ ▋▊▍ ▊▄▄ ▇▉▍▄ ▉▊▉ ▇▄▄▍▌▌ ▉▆ ▋▇▋ ▋▌▋▉▍▊ ▊▋ ▇▄▄ ▄▉▍▅▊▋▆▄ ▇▇▋ ▆▇▅██ ▅▊▄█▍▆▆ ▍▆▇▋▊▆▇▋ ▆▉▇▄▉▄▋▅▋ ▄▊▄▇▄ ▉▇ ▇▉▆█▅ ▇▉ ▄▋▆ ▄▍▆▍▉▌ ▍▊█▋▄ ▅▌██▉▆█▇▆ ▌▌▊▄▇▄▍▍
Optimize network thread's batching overhead slightly
- during the end of frame flush only set the last batch sent as "immediate" priority
- avoids paying the extra 0.4us to wake the RakNet thread after every single batch sent, instead only paying it once for the entire batch
Add unordered batch alongside the ordered one so we keep sending position packets unordered while keeping them batched
- my previous commits were incorrect: positions have always been sent unordered
█ ▉▄▍▉▉█▄ ▉▌▊▊ ▅██▍▉▇▅▊█▇ ▇▄█▌▊▅▋ ▉▅▇▆▌ ▋▊▆ ▅▌▄▍▇▄ ▉▄▉█ ▍▇▄█ ▇▋▇▄▄▅▍█ ▋ ▌▆▇▍ ▊▆▇▆ ▊▋▋▇█